@@ -1,6 +1,6 @@
 import re
 from datetime import datetime
-from typing import TYPE_CHECKING, Any, Dict, List, Tuple, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Sequence, Tuple, Union, cast
 
 import cognite.client.utils._time
 from cognite.client import utils
@@ -20,7 +20,7 @@ class SyntheticDatapointsAPI(APIClient):
 
     def query(
         self,
-        expressions: Union[str, "sympy.Expr", List[Union[str, "sympy.Expr"]]],
+        expressions: Union[str, "sympy.Expr", Sequence[Union[str, "sympy.Expr"]]],
         start: Union[int, str, datetime],
         end: Union[int, str, datetime],
         limit: int = None,
@@ -31,7 +31,7 @@ class SyntheticDatapointsAPI(APIClient):
         """`Calculate the result of a function on time series. <https://docs.cognite.com/api/v1/#operation/querySyntheticTimeseries>`_
 
         Args:
-            expressions (Union[str, "sympy.Expr", List[Union[str, "sympy.Expr"]]]): Functions to be calculated. Supports both strings and sympy expressions. Strings can have either the API `ts{}` syntax, or contain variable names to be replaced using the `variables` parameter.
+            expressions (Union[str, "sympy.Expr", Sequence[Union[str, "sympy.Expr"]]]): Functions to be calculated. Supports both strings and sympy expressions. Strings can have either the API `ts{}` syntax, or contain variable names to be replaced using the `variables` parameter.
             start (Union[int, str, datetime]): Inclusive start.
             end (Union[int, str, datetime]): Exclusive end
             limit (int): Number of datapoints per expression to retrieve.
@@ -69,7 +69,9 @@ class SyntheticDatapointsAPI(APIClient):
             limit = cast(int, float("inf"))
 
         tasks = []
-        expressions_to_iterate = expressions if isinstance(expressions, List) else [expressions]
+        expressions_to_iterate = (
+            expressions if (isinstance(expressions, Sequence) and not isinstance(expressions, str)) else [expressions]
+        )
 
         for i in range(len(expressions_to_iterate)):
             expression, short_expression = self._build_expression(
